Learn R Programming

datadrivencv (version 0.1.0)

build_network_logo: Build interactive network logo

Description

Constructs a network based on your position data to be used as a logo. Interactive in HTML version and static in the PDF version. Notes are entries, colored by section and connected if they occurred in the same year

Usage

build_network_logo(position_data)

Arguments

position_data

position data from your CV_Printer class.

Value

Interactive force-directed layout network of your CV data